#
#
# bonding.py - bluetooth bonding procedures
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import dbus

_ = Globals._

class bonding():
	
	def __init__(self, hci):
		
		self.bus = dbus.SystemBus();
		self.obj = self.bus.get_object('org.bluez', '/org/bluez/'+hci)
		self.adapter = dbus.Interface(self.obj, 'org.bluez.Adapter')
		
		self.hci = hci
		self.bus.add_signal_receiver(self.bonding_created_signal, 'BondingCreated', 'org.bluez.Adapter', 'org.bluez', None)

		
	def Deinit(self):
		self.bus.remove_signal_receiver(self.bonding_created_signal, 'BondingCreated', 'org.bluez.Adapter', 'org.bluez', None)
		
		
	def bonding_created_signal(self,bdaddr):
       		self.on_bonding_finished((True,bdaddr))

	
	def Create(self,addr):
		self.adapter.CreateBonding(addr, reply_handler=self.BondingReply, error_handler=self.BondingError)
		return True
		
	
	def BondingReply(self):
		pass
		
	
	def BondingError(self,err):
		self.on_bonding_finished((False,err))
		

	def Remove(self,addr):
		handle = self.adapter.RemoveBonding(addr)
		return True
	
	def on_bonding_finished(self, result):
		#print "finished"
		if result[0]:
			Globals.Statusbar.push(_("Bonding successful."))
			addr = result[1]
			Globals.toolbar.bond1.set_label("Unbond");
			
			if Globals.Settings.other_notifications:
				Globals.Notification.show(_("Bonding successful."), _("Bonding with %(addr)s (%(name)s created") % {"addr":addr,"name":Globals.adapter.GetRemoteName(addr)}, im="lock_bt.png" )
			
			for i in range(Globals.main_list.row_count):
				rdata = Globals.main_list.get_row(i)
				
				bonded = rdata[3]
				connected =rdata[2]
				bdaddr = rdata[0]
				

				if bdaddr == addr:
					iter = Globals.main_list.get_iter_by_row(i)
					Globals.main_list.set_pixbuf(iter, 6, "hasbonding.png")
					Globals.main_list.set_data(iter, 8, True)
			
		else:
			Globals.Statusbar.push(_("Bonding Failed."))
			print result[1]

