#
#
# dbusAgent.py - dbus agent module
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals

import dbus
import dbus.service
import gtk
import threading
import subprocess
import time
import os

from blueman.Gui.auth_dialog import auth_dialog
from blueman.Gui.bond_dialog import bond_dialog
from blueman.Gui.question_box import question_box

_ = Globals._


class dbusAgent(dbus.service.Object):
	def __init__(self, path):

		
		self.bus = dbus.SystemBus();
		
		
		Globals.dbg.info("Initializing 'Bluetooth.dbusAgent' Class", 6)

		dbus.service.Object.__init__(self, self.bus, path)
		self.registered=False
		
		self.auth_in_progress = False
		self.auth_dialog = None

	def register(self):
		#def bla(self):
			
			 
		pipe = subprocess.Popen('ps -A | grep "bluetooth-appl"', shell=True, stdout=subprocess.PIPE).stdout
		data = pipe.read()
		if len(data) > 0:
			#print "a"
			if not Globals.Settings.replace_agent_by_default:
				q = question_box()
				res =  q.run()
			else:
				res = True
			
			if res:
				Globals.dbg.info("Killing Bluetooth applet", 5)
				os.system("killall bluetooth-applet")
				time.sleep(0.1)
			else:
				return 0
		
		
		
		self.obj = self.bus.get_object('org.bluez', '/org/bluez')
		security = dbus.Interface(self.obj, 'org.bluez.Security')
		security.RegisterDefaultPasskeyAgent("/org/bluez/blueman")
		Globals.dbg.info("Passkey agent registered", 5)

		security.RegisterDefaultAuthorizationAgent("/org/bluez/blueman")
		Globals.dbg.info("Authorization agent registered", 5)
		self.registered=True



	@dbus.service.method(dbus_interface='org.bluez.PasskeyAgent')

	def Complete(self, *args):
		print "Complete"
		#print args


	@dbus.service.method(dbus_interface='org.bluez.PasskeyAgent', in_signature='ssb', out_signature='s', async_callbacks=("ok","err"))

	def Request(self, path, address, numeric, ok, err):

		Globals.dbg.info("Bonding Request For %s" % address, 5)
		
		Globals.Notification.show(_("Bonding request"),_("Bonding Request For %(addr)s (%(name)s)") % {"addr": address, "name": Globals.adapter.GetRemoteName(address) }, im="bond_bt.png" )
		threading.Thread(target=self.passkey_handler, args=(ok, err, address,)).start()
		
	def passkey_handler(self, ok, err, address):
		event = threading.Event()


		Globals.Statusbar.push(_("Connected. Waiting for passkey"))
		dialog = bond_dialog(event, address, Globals.adapter.GetRemoteName(address))
		
		event.wait(15)
		resp = dialog.get_response()
		if resp == None:
			err(dbus.DBusException("org.bluez.Error.Canceled"))
			Globals.dbg.warn("Bonding has timed out", 5)

		if resp == gtk.RESPONSE_OK:
			Globals.Statusbar.push(_("Passkey sent. Waiting for confirmation"))
			ok(dialog.get_passkey())
			dialog.destroy()
		else:
			err(dbus.DBusException("org.bluez.Error.Rejected"))
			dialog.destroy()
		
	
	@dbus.service.method(dbus_interface='org.bluez.PasskeyAgent')

	def Confirm(self, *args):
		print "confirm"
		#print args
		
	
	
	@dbus.service.method(dbus_interface='org.bluez.PasskeyAgent')

	def Cancel(self, *args):
		print "cancel"
		#print args
		
	@dbus.service.method(dbus_interface='org.bluez.AuthorizationAgent', in_signature='ssss', out_signature='', async_callbacks=("ok","err"))
	
	def Authorize(self, adapter_path, address, service_path, uuid, ok, err):
		if self.auth_in_progress:
			return 0
		
		Globals.dbg.info("Authorization Request For %s" % address, 5)
		self.auth_in_progress = True
		obj = self.bus.get_object('org.bluez', service_path)
		service = dbus.Interface(obj, 'org.bluez.Service')
		desc = service.GetDescription()
		
		threading.Thread(target=self.auth_handler, args=(ok, err, address, desc,)).start()

		
	@dbus.service.method(dbus_interface='org.bluez.AuthorizationAgent', in_signature='ssss', out_signature='')
	def Cancel(self, adapter_path, address, service_path, uuid):
		if not self.auth_in_progress:
			return 0
		else:
			self.auth_dialog.event.set()
			self.auth_dialog.close()
			self.auth_in_progress = False
		
	def auth_handler(self, ok, err, address, desc):
		evt = threading.Event()
		self.auth_dialog = auth_dialog(evt, address, desc)
		evt.wait(15)

		result = self.auth_dialog.get_result()
		if result == None:
			Globals.dbg.warn("Authorization has timed out", 5)

			
		#authorize
		if result == gtk.RESPONSE_OK:
			ok()
		#reject
		elif result == gtk.RESPONSE_REJECT:
			err(dbus.DBusException("org.bluez.Error.Rejected"))
		#trust
		elif result == gtk.RESPONSE_YES:
			Globals.adapter.SetTrusted(address)
			ok()
		#X
		else:
			err(dbus.DBusException("org.bluez.Error.Canceled"))
			
		time.sleep(0.1)
		self.auth_dialog.close()
		self.auth_in_progress = False

