#
#
# blueman - bluetooth inquiry module
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import dbus

from blueman.Main.address_cache import address_cache as _cache
from blueman.Gui.statusbar_with_inquiry import statusbar_with_inquiry

_ = Globals._
ngettext = Globals.ngettext

class inquiry():
	def __init__(self, hci):
		Globals.dbg.info("Initializing 'Bluetooth.inquiry' Class", 6)
		self.bus = dbus.SystemBus();
		self.obj = self.bus.get_object('org.bluez', '/org/bluez/'+hci)
		self.adapter = dbus.Interface(self.obj, 'org.bluez.Adapter')
				
		
		self.bus.add_signal_receiver(self.disc_started_signal, 'DiscoveryStarted', 'org.bluez.Adapter', 'org.bluez', '/org/bluez/'+hci)
		self.bus.add_signal_receiver(self.rem_dev_found_signal, 'RemoteDeviceFound', 'org.bluez.Adapter', 'org.bluez', '/org/bluez/'+hci)
		self.bus.add_signal_receiver(self.disc_completed_signal, 'DiscoveryCompleted', 'org.bluez.Adapter', 'org.bluez', '/org/bluez/'+hci)
		self.bus.add_signal_receiver(self.on_remote_name_updated, 'RemoteNameUpdated', 'org.bluez.Adapter', 'org.bluez', '/org/bluez/'+hci)
		self.bus.add_signal_receiver(self.on_RemoteNameFailed, 'RemoteNameFailed', 'org.bluez.Adapter', 'org.bluez', '/org/bluez/'+hci)

		#self.bus.remove_signal_receiver(self.disc_started_signal, 'org.bluez.Adapter', 'org.bluez', '/org/bluez/hci0')
		
		self.hci = hci

		self.active = False
		self.dev_count = 0
		self.unnamed = []
		self.devices = []
		
	
	def Deinit(self):
		Globals.dbg.info("Deinitializing 'Bluetooth.inquiry' Class", 6)
		self.bus.remove_signal_receiver(self.disc_started_signal, 'DiscoveryStarted', 'org.bluez.Adapter', 'org.bluez', '/org/bluez/'+self.hci)
		self.bus.remove_signal_receiver(self.rem_dev_found_signal, 'RemoteDeviceFound', 'org.bluez.Adapter', 'org.bluez', '/org/bluez/'+self.hci)
		self.bus.remove_signal_receiver(self.disc_completed_signal, 'DiscoveryCompleted', 'org.bluez.Adapter', 'org.bluez', '/org/bluez/'+self.hci)
		self.bus.remove_signal_receiver(self.on_remote_name_updated, 'RemoteNameUpdated', 'org.bluez.Adapter', 'org.bluez', '/org/bluez/'+self.hci)
		self.bus.remove_signal_receiver(self.on_RemoteNameFailed, 'RemoteNameFailed', 'org.bluez.Adapter', 'org.bluez', '/org/bluez/'+self.hci)
	
	def CancelDiscovery(self):
		self.adapter.CancelDiscovery()
		self.active = False
	
	
	def StartInquiry(self):
		#main_list.set_row_by_address("Test")
		Globals.main_list.reset()
		self.adapter.DiscoverDevices();
		
		Globals.toolbar.disable_buttons()
		Globals.toolbar.inquiry1.set_sensitive(True)
		Globals.toolbar.set_icon(Globals.toolbar.inquiry1, Globals.IMAGE_DIR + "/stop.png")
		Globals.toolbar.inquiry1.set_label(_("Cancel"))

		self.unnamed = []
		self.devices = []
		self.active = True
		self.dev_count = 0
		
		self.statusbar = statusbar_with_inquiry()
		self.statusbar.inquiry_start()
	
	
	def on_remote_name_updated(self, address, name):
		Globals.dbg.info("Inquiry: Remote Name Updated (%s, %s)" % (address, name), 5)
		cache = _cache()
		Globals.main_list.edit_row(address, name)
		cache.push(address, name)
		try:
			self.unnamed.remove(address)
		except:
			pass
		
	def on_RemoteNameFailed(self, address):
		Globals.dbg.info("Inquiry: Remote Name Failed (%s)" % address, 5)
		Globals.main_list.edit_row(address)
		
		cache = _cache()
		old = cache.pull(address)
		if not old:
			cache.push(address, "N/A")
		try:
			self.unnamed.remove(address)
		except:
			pass

	
	def disc_started_signal(self):
		#self.inq_progress = gui.inquiry_progress()
		Globals.dbg.info("Inquiry Started", 5)

	def rem_dev_found_signal(self,address, cls, rssi):
		#print 'Signal: RemoteDeviceFound(%s, %s, %s)' % (address, cls, rssi)

		rssi_perc = 100 - float(rssi) / -127*100

		if not address in self.devices:
			Globals.dbg.info("Inquiry: Device Found (%s)" % address, 5)
			self.dev_count += 1
			self.unnamed.append(address)
			self.devices.append(address)
			Globals.main_list.add_from_list([[address, _("Updating..."),rssi_perc]], False)
			Globals.Statusbar.push( ngettext("Found %s Device", "Found %s Devices", Globals.main_list.row_count) % Globals.main_list.row_count)
		else:
			#set_signal(self, addr, value, pb_col, data_col, im_prefix, im_suffix):
			Globals.main_list.set_signal(address, rssi_perc, 5, 11, "/signal/rssi/rssi_", ".png")

	        

	def disc_completed_signal(self):
		Globals.dbg.info("Inquiry Complete", 5)
		self.statusbar.inquiry_finish()
		
		del self.statusbar


		self.active = False
		Globals.toolbar.set_icon(Globals.toolbar.inquiry1, Globals.IMAGE_DIR + "/inquiry.png")
		Globals.toolbar.inquiry1.set_label(_("Inquiry"))

		for i in range(len(self.unnamed)):
			Globals.main_list.edit_row(self.unnamed[i])
			

