#
#
# manager.py - bluez manager interface
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import dbus
import dbus.glib

_ = Globals._

class manager():
				
	def __init__(self):
		Globals.dbg.info("Initializing 'Bluetooth.manager' Class", 6)
		
		self.bus = dbus.SystemBus();
		self.obj = self.bus.get_object('org.bluez', '/org/bluez')
		self.manager = dbus.Interface(self.obj, 'org.bluez.Manager')
		
		self.bus.add_signal_receiver(self.on_adapter_added, 'AdapterAdded', 'org.bluez.Manager', 'org.bluez', '/org/bluez')
		self.bus.add_signal_receiver(self.on_adapter_removed, 'AdapterRemoved', 'org.bluez.Manager', 'org.bluez', '/org/bluez')

		
	def ListAdapters(self):
		return self.manager.ListAdapters()
		
	def DefaultAdapter(self):
		return self.manager.DefaultAdapter()

        def ListServices(self):
            return self.manager.ListServices()

	
	def on_adapter_added(self, path):
		self.on_adapter_xtach(True, path)
	
	
	def on_adapter_removed(self, path):
		self.on_adapter_xtach(False, path)
		
		
	def on_adapter_xtach(self, status, path):	
		hci = path.split("/")[3]
		
		
		if not status:
			#if all adapters are removed
			adapters = Globals.Manager.ListAdapters()

			if len(adapters) == 0:
				Globals.Statusbar.push(_("No Adapters Found"))
				
				if Globals.Settings.other_notifications:
					Globals.Notification.show(_("Adapter Detached"), _("Adapter %s Detached. No more adapters available.") % hci, im="mydevice.png")
				
				Globals.toolbar.disable_all_buttons()
				Globals.main_list.reset()
				#menu_services.set_sensitive(False)
				Globals.deinit_adapter()
				
				
			else:
				#if current adapter disconnected 
				if not "/org/bluez/"+Globals.Settings.adapter in adapters:
					new = adapters[0].split("/")[3]
					Globals.Settings.adapter = new
					if Globals.Settings.other_notifications:
						Globals.Notification.show(_("Adapter Detached"), _("Adapter %(hci)s Detached. Switching to adapter %(new)s.") % {"hci":hci, "new":new}, im="mydevice.png")
					#initialise the new adapter 
					Globals.init_adapter(new)
					
				else:
					if Globals.Settings.other_notifications:
						Globals.Notification.show(_("Adapter Detached"), _("Adapter %(hci)s Detached.") % {"hci":hci}, im="mydevice.png")
	
				
				
					
		else:

			if Globals.Settings.other_notifications:
				Globals.Notification.show(_("Adapter Attached"), _("Adapter %s attached.") % (hci), im="mydevice.png" )
			
			#device attached
			adapters = Globals.Manager.ListAdapters()
			if len(adapters) == 1:	
				#the single adapter connected
				
				Globals.toolbar.enable_main_buttons()
				
				new = adapters[0].split("/")[3]
				
				#menu_services.set_sensitive(True)
				
				Globals.Settings.adapter = new
				
				Globals.init_adapter(new)
				Globals.Statusbar.push(_("Ready"))

