#
#
# blueman - main_window library
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import gtk

from blueman.Services.service_manager import service_manager
from blueman.Gui.settings_dialog import settings_dialog
from blueman.Gui.about import about


_ = Globals._

class main_window():
	
	def __init__(self, xml):
		
		self.xml = xml
		self.window = self.xml.get_widget("window1");
		
		version = Globals.VERSION
		subversion = Globals.SVN_REVISION
		if subversion == "":
			sep = ""
		else:
			sep = " svn-"
		
		self.window.set_title(_("Bluetooth Manager") + " " + version + sep + subversion);
		self.window.set_icon_from_file(Globals.IMAGE_DIR + "/bluetooth.png")
		self.page = ""
		self.xml.signal_connect("on_window_quit", self.on_window_quit)
		self.xml.signal_connect("on_preferences_activate", self.on_preferences_activate)
		
		self.mi_trust = xml.get_widget("mi_trust")
		self.xml.signal_connect("on_mi_trust_activate", self.on_mi_trust_activate)
		self.xml.signal_connect("on_mi_disconnect_activate", self.on_mi_disconnect_activate)
		self.xml.signal_connect("on_services_activate", self.on_services_activate)
		self.xml.signal_connect("on_about1_activate", self.on_about1_activate)
		self.xml.signal_connect("on_trans_activate", self.on_trans_activate)
		
		self.mi_disconnect = xml.get_widget("mi_disconnect")
		
		im = self.mi_trust.get_image()
		im.set_from_file(Globals.IMAGE_DIR + "/trust16.png")
		
		if not Globals.Settings.open_in_tray:
			self.show()
		
		
		
	def set_handler(self, event, func):	
		self.xml.signal_connect(event,func)
		
		
	def show(self):
		self.window.show()
		
	def hide(self):
		self.window.hide()
		
	def visible(self):
		return self.window.get_property("visible")
			
		
	
	def on_window_quit(self, window, *arg):
		if Globals.Settings.close_to_tray and window == self.window:
			self.window.hide()
			return True
		
		Globals.KILL = True
		gtk.main_quit()
		return False
		
	def on_preferences_activate(self, *args):
		settings_dialog()

		
		
	def on_mi_trust_activate(self, widget):
		row = Globals.main_list.get_selected_row()
		if Globals.adapter.IsTrusted(row[0]):
			Globals.adapter.RemoveTrust(row[0])
			self.mi_trust.get_child().set_text(_("Set Trusted"))
			
			im = Globals.window.mi_trust.get_image()
			im.set_from_file(Globals.IMAGE_DIR + "/trust16.png")
			
		else:
			Globals.adapter.SetTrusted(row[0])
			self.mi_trust.get_child().set_text(_("Remove Trust"))
			im = self.mi_trust.get_image()
			im.set_from_file(Globals.IMAGE_DIR + "/trust16_g.png")
		
		#window.mi_trust.set_sensitive(False)
		
	def on_mi_disconnect_activate(self, widget):
		row = Globals.main_list.get_selected_row()

		Globals.adapter.DisconnectRemoteDevice(row[0], error_handler=self.disconnect_err, reply_handler=self.disconnect_reply)
		self.mi_disconnect.set_sensitive(False)

			
			
	def disconnect_err(self, err, *args):
		Globals.Statusbar.push(_("Failed To Disconnect Device"))
		
	def disconnect_reply(self):
		pass
	
	def on_services_activate(self, widget):
		service_manager()
		
	
	def on_trans_activate(self, widget):
		os.system("firefox https://translations.launchpad.net/blueman/ &")

	def on_about1_activate(self, widget):
		about()

