#
#
# blueman - my_device module
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import gtk 

_ = Globals._
ngettext = Globals.ngettext

class my_device:
			
	def __init__(self):		
			
		self.xml = gtk.glade.XML(Globals.GLADE_DIR + "/my_device.glade")
		self.xml.signal_autoconnect(self)
		self.dialog = self.xml.get_widget("mydevice")
		self.slider = self.xml.get_widget("hscale1")
		self.name = self.xml.get_widget("name")
		self.combobox = self.xml.get_widget("class")
		self.dialog.set_icon_from_file(Globals.IMAGE_DIR + "/bluetooth.png")
		
		
		im = self.xml.get_widget("image2");
		im.set_from_file(Globals.IMAGE_DIR + "/services.png")
		
		im = self.xml.get_widget("image1");
		im.set_from_file(Globals.IMAGE_DIR + "/properties16.png")
		
		timeout = Globals.adapter.GetDiscoverableTimeout()
		self.slider.set_value(timeout/60)
		
		self.dev_name = Globals.adapter.GetName()
		self.name.set_text(self.dev_name)
		
		#Globals.adapter.SetMinorClass("laptop")
		self.minor = Globals.adapter.GetMinorClass()
		
		
		
		self.liststore = gtk.ListStore(str, str)
		self.combobox.set_model(self.liststore)
		
		cell = gtk.CellRendererText()
		self.combobox.pack_start(cell, True)
		#self.combobox.add_attribute(cell, 'markup', 0) 
		
		
		
		self.liststore.append(["Desktop Computer","desktop"])
		self.liststore.append(["Laptop Computer","laptop"])
		self.liststore.append(["Server","server"])
		self.liststore.append(["Unspecified","uncategorized"])
		
		self.liststore.foreach(self.iter_func)
		
		self.limited = self.xml.get_widget("radiobutton4")
		self.discoverable = self.xml.get_widget("radiobutton1")
		self.connectable = self.xml.get_widget("radiobutton2")
		self.off = self.xml.get_widget("radiobutton5")
		
		self.mode = Globals.adapter.GetMode()
		
		try:
			self.modes = Globals.adapter.ListAvailableModes()
		except:
			self.limited.set_sensitive(False)
		
		if self.mode == "connectable":
			self.connectable.set_active(True)
			self.slider.set_sensitive(False)
		elif self.mode == "discoverable":
			self.discoverable.set_active(True)
		elif self.mode == "limited":
			self.limited.set_active(True)
		else:
			self.slider.set_sensitive(False)
			self.off.set_active(True)
		

		
		
		self.lbversion = self.xml.get_widget("label15")
		self.lrevision = self.xml.get_widget("label16")
		self.lmanufacturer = self.xml.get_widget("label17")
		self.lcompany = self.xml.get_widget("label19")
		self.lmajorclass = self.xml.get_widget("label18")
		self.lminorclass = self.xml.get_widget("label20")
		self.lname = self.xml.get_widget("label21")
		self.laddress = self.xml.get_widget("label27")
		
		try:
			self.lbversion.set_text(Globals.adapter.GetVersion())
		except:
			self.lbversion.set_text(_("Not Available"))
			
		try:
			self.lrevision.set_text(Globals.adapter.GetRevision())
		except:
			self.lrevision.set_text(_("Not Available"))
		
		try:
			self.lmanufacturer.set_text(Globals.adapter.GetManufacturer())
		except:
			self.lmanufacturer.set_text(_("Not Available"))
			
		try:
			self.lcompany.set_text(Globals.adapter.GetCompany())
		except:
			self.lcompany.set_text(_("Not Available"))
			
		try:
			self.lmajorclass.set_text(Globals.adapter.GetMajorClass())
		except:
			self.lmajorclass.set_text(_("Not Available"))

		try:
			self.lminorclass.set_text(Globals.adapter.GetMinorClass())
		except:
			self.lminorclass.set_text(_("Not Available"))

		try:
			self.lname.set_text(Globals.adapter.GetName())
		except:
			self.lname.set_text(_("Not Available"))	
			
		try:
			self.laddress.set_text(Globals.adapter.GetAddress())
		except:
			self.laddress.set_text(_("Not Available"))	
		
		
		
		self.run()
	
	
	
	def on_mode_toggled(self, button):
		if button.get_active():
			if button == self.limited:
				Globals.adapter.SetMode("limited")
			elif button == self.discoverable:
				self.slider.set_sensitive(True)
				Globals.adapter.SetMode("discoverable")
			elif button == self.connectable:
				self.slider.set_sensitive(False)
				Globals.adapter.SetMode("connectable")
			elif button == self.off:
				self.slider.set_sensitive(False)
				Globals.adapter.SetMode("off")
	
	
	def iter_func(self, model, path, iter):
		if model.get(iter,1)[0] == self.minor:
			self.combobox.set_active_iter(iter)
	
	
	def on_slider_changed(self, slider):
		time = int(slider.get_value())*60
		Globals.adapter.SetDiscoverableTimeout(time)

			
			
	def on_slider_format(self, slider, value):
		if value == 0:
			return _("Always Visible")
		return  ngettext("%i Minute", "%i Minutes", value) % value

		
	def on_class_changed(self, widget):
		newclass = self.liststore.get(widget.get_active_iter(),1)[0]
		Globals.adapter.SetMinorClass(newclass)

	
	
	def run(self):

	
		response = self.dialog.run()

		if not self.name.get_text() == self.dev_name:
			Globals.adapter.SetName(self.name.get_text())


		if response == gtk.RESPONSE_CLOSE or gtk.RESPONSE_NONE:
			self.dialog.destroy()
			return False
	
		else:			
			self.dialog.destroy()
			return True

