#
#
# blueman - properties module
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import gtk
import threading

_ = Globals._

class properties:
	
	def __init__(self):	
	
		
		self.xml = gtk.glade.XML(Globals.GLADE_DIR + "/properties.glade")
		self.xml.signal_autoconnect(self)

		self.dialog = self.xml.get_widget("properties");
		self.dialog.set_icon_from_file(Globals.IMAGE_DIR + "/properties.png")

		im = self.xml.get_widget("image3");
		im.set_from_file(Globals.IMAGE_DIR + "/services.png")

		im = self.xml.get_widget("image4");
		im.set_from_file(Globals.IMAGE_DIR + "/properties16.png")

		but = self.xml.get_widget("button3");
		im = gtk.Image()
		im.set_from_file(Globals.IMAGE_DIR + "/inquiry16.png")
		but.set_image(im)




		#-- service list

		self.service_treeview = self.xml.get_widget("treeview1");

		self.service_list = gtk.ListStore(str,str)
		self.service_treeview.set_model(self.service_list)


		cell = gtk.CellRendererText()


		tvcolumn = gtk.TreeViewColumn(_('Name'))
		tvcolumn2 = gtk.TreeViewColumn(_('Channel'))

		self.service_treeview.append_column(tvcolumn)
		self.service_treeview.append_column(tvcolumn2)

		tvcolumn.pack_start(cell, True)
		tvcolumn2.pack_start(cell, True)

		tvcolumn.set_attributes(cell, markup=0)
		tvcolumn2.set_attributes(cell, markup=1)


		#---
		button = self.xml.get_widget("button3");
		button.set_sensitive(True)
		button.set_label(_("Get Service List"))

		lversion = self.xml.get_widget("label16");
		lrevision = self.xml.get_widget("label17");
		lmanufacturer = self.xml.get_widget("label18");
		lcompany = self.xml.get_widget("label19");
		lmajorclass = self.xml.get_widget("label20");
		lminorclass = self.xml.get_widget("label21")
		ldevname = self.xml.get_widget("label22")
		ldevaddress = self.xml.get_widget("label23");
		llastseen = self.xml.get_widget("label24");
		llastused = self.xml.get_widget("label25");
		lbonded = self.xml.get_widget("label26");
		lconnected = self.xml.get_widget("label27");


		addr = Globals.main_list.get_selected_row()[0]
		
		
			
		try:	
			version = Globals.adapter.GetRemoteVersion(addr)
			lversion.set_label(version)
		except:
			lversion.set_label(_("Not Available"))
		
		
		try:
			connected = Globals.adapter.IsConnected(addr)
			if connected:
				lconnected.set_label(_("Yes"))
			else:
				lconnected.set_label(_("No"))
		except:
			lconnected.set_label(_("Not Available"))
		
		try:
			name = Globals.adapter.GetRemoteName(addr)
			ldevname.set_label(name)
		except:
			ldevname.set_label(_("Not Available"))
		
		try:
			minorclass = Globals.adapter.GetRemoteMinorClass(addr)
			lminorclass.set_label(minorclass)
		except:
			lminorclass.set_label(_("Not Available"))
			
			
		try:
			majorclass = Globals.adapter.GetRemoteMajorClass(addr)
			lmajorclass.set_label(majorclass)
		except:
			lmajorclass.set_label(_("Not Available"))
		
		try:
			manufacturer = Globals.adapter.GetRemoteManufacturer(addr)
			lmanufacturer.set_label(manufacturer)
		except:
			lmanufacturer.set_label(_("Not Available"))
		
		try:
			lastseen = Globals.adapter.LastSeen(addr)
			llastseen.set_label(lastseen)
		except:
			llastseen.set_label(_("Not Available"))
		
		try:
			lastused = Globals.adapter.LastUsed(addr)
			llastused.set_label(lastused)
		except:
			llastused.set_label("Not Available")
		
		try:
			bonded = Globals.adapter.HasBonding(addr)
			if bonded:
				lbonded.set_label(_("Yes"))
			else:
				lbonded.set_label(_("No"))
		except:
			lbonded.set_label(_("Not Available"))
		
		try:
			revision = Globals.adapter.GetRemoteRevision(addr)
			lrevision.set_label(revision)
		except:
			lrevision.set_label(_("Not Available"))
		
		
		try:
			company = Globals.adapter.GetRemoteCompany(addr)
			lcompany.set_label(company)
			
		except:
			
			lcompany.set_label(_("Not Available"))

		

		ldevaddress.set_label(addr)
		
		

	def set_text(self, text):
		self.label.set_text(text)
		
	def run(self):
	
		response = self.dialog.run()
		if response == gtk.RESPONSE_CLOSE:
			self.dialog.destroy()
			return True
		
		elif response == gtk.RESPONSE_HELP:
			self.dialog.destroy()
			return False
			
		else:			
			self.dialog.destroy()
			return False
			

	
	def on_get_service_list_clicked(self, button):

		self.service_list.clear()
		threading.Thread(target=self.get_service_list_thread, args=(Globals.main_list.get_selected_row()[0],self.get_service_list,)).start()
		
		button = self.xml.get_widget("button3");
		button.set_sensitive(False)
		button.set_label(_("Please wait..."))
		
		

	def get_service_list_thread(self, addr,func):
		services = Globals.adapter.GetRemoteServices(addr)
		if not services:
			func(False)
		if Globals.main_list.get_selected_row()[0] == addr:
			func(services)			
		
		
	def get_service_list(self, services):
		button = self.xml.get_widget("button3");
		button.set_sensitive(True)
		button.set_label(_("Get Service List"))
		
		if not services:
			Globals.Statusbar.push(_("Failed to get service list or no services available"))
			return 0
		

		for i in range(len(services)):
			if services[i]["name"] and services[i]["port"]:
			       	self.service_list.append([services[i]["name"],services[i]["port"]])

