#
#
# blueman - settings_dialog module
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
from blueman.Gui.generic_dialog import generic_dialog
import gtk

_ = Globals._

class settings_dialog( generic_dialog ):
	
	def __init__(self):
		generic_dialog.__init__(self, "preferences.glade", "prefs")
		
		
		self.checkbutton1 = self.xml.get_widget("checkbutton1")
		self.checkbutton2 = self.xml.get_widget("checkbutton2")
		self.checkbutton3 = self.xml.get_widget("checkbutton3")
		self.checkbutton4 = self.xml.get_widget("checkbutton4")
		self.checkbutton5 = self.xml.get_widget("checkbutton5")
		self.checkbutton6 = self.xml.get_widget("checkbutton6")
		self.combo = self.xml.get_widget("combobox1")

		
		self.liststore = gtk.ListStore(str)
		self.combo.set_model(self.liststore)
		
		cell = gtk.CellRendererText()
		self.combo.pack_start(cell, True)
		self.combo.add_attribute(cell, 'markup', 0) 
		
		
		if Globals.Settings.connection_notifications:
			self.checkbutton3.set_active(True)
	
		if Globals.Settings.other_notifications:
			self.checkbutton4.set_active(True)
			
		if Globals.Settings.close_to_tray:
			self.checkbutton1.set_active(True)
			
		if Globals.Settings.open_in_tray:
			self.checkbutton2.set_active(True)
			
		if Globals.Settings.passkey_agent:
			self.checkbutton5.set_active(True)
		else:
			self.checkbutton6.set_sensitive(False)
			
		if Globals.Settings.replace_agent_by_default:
			self.checkbutton6.set_active(True)
			
		adapters = Globals.Manager.ListAdapters()
		
		if len(adapters) == 0:
			self.combo.set_sensitive(False)
		
		for i in range(len(adapters)):
			 adapter = adapters[i].split("/")[3]
			 self.liststore.append([adapter])
			 #print adapter
			 #print Globals.Settings.adapter
			 if Globals.Settings.adapter == adapter:
			 	self.combo.set_active(i)
			 	
			 	
		self.xml.get_widget("sp_year").set_text(str(Globals.Settings.ls_year))
		self.xml.get_widget("sp_mon").set_text(str(Globals.Settings.ls_mon))
		self.xml.get_widget("sp_day").set_text(str(Globals.Settings.ls_day))
		
		self.xml.signal_autoconnect(self)
			 
		
			
			
	def on_checkbutton1_toggled(self, widget):
		if widget.get_active():
			Globals.Settings.close_to_tray=True
		else:
			Globals.Settings.close_to_tray=False
			
	def on_checkbutton2_toggled(self, widget):
		if widget.get_active():
			Globals.Settings.open_in_tray=True
		else:
			Globals.Settings.open_in_tray=False
			
	def on_checkbutton3_toggled(self, widget):
		if widget.get_active():
			Globals.Settings.connection_notifications=True
		else:
			Globals.Settings.connection_notifications=False
			
	def on_checkbutton4_toggled(self, widget):
		if widget.get_active():
			Globals.Settings.other_notifications=True
		else:
			Globals.Settings.other_notifications=False
			
			
	def on_checkbutton5_toggled(self, widget):
		if widget.get_active():
			Globals.Settings.passkey_agent=True
			self.checkbutton6.set_sensitive(True)
		else:
			Globals.Settings.passkey_agent=False
			self.checkbutton6.set_sensitive(False)
			
			
	def on_checkbutton6_toggled(self, widget):
		if widget.get_active():
			Globals.Settings.replace_agent_by_default=True
		else:
			Globals.Settings.replace_agent_by_default=False
		
		
	def on_combobox1_changed(self, widget):
		
		iter = self.combo.get_active_iter()
		dev = self.liststore.get(iter,0)
		Globals.Settings.adapter = dev[0]
		Globals.deinit_adapter()
		Globals.init_adapter(Globals.Settings.adapter)
		
	def dialog_response(self, dialog, response):

		ls_year = self.xml.get_widget("sp_year").get_text()
		ls_mon = self.xml.get_widget("sp_mon").get_text()
		ls_day = self.xml.get_widget("sp_day").get_text()
		
		Globals.Settings.set("ls_year", ls_year)
		Globals.Settings.set("ls_mon", ls_mon)
		Globals.Settings.set("ls_day", ls_day)
		
		Globals.Settings.save()
		
		return False
		


