#
#
# blueman - statusbar_with_stats module
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals

import blueman.blueman as blueman
import gobject
import gtk
from blueman.Gui.animation import animation
from blueman.Gui.statusbar import statusbar
from blueman.Main.speed_calc import speed_calc


class statusbar_with_stats(statusbar):
	
	def __init__(self):
		
		self.adapter = Globals.Settings.adapter
		
		self.time= None
		
		self.up_speed = speed_calc()
		self.down_speed = speed_calc()
			
		self.statusbar = Globals.Statusbar.statusbar
		self.statusbar_container = Globals.Statusbar.statusbar_container

		up = gtk.gdk.pixbuf_new_from_file(Globals.IMAGE_DIR + "/up_inactive.png")
		down = gtk.gdk.pixbuf_new_from_file(Globals.IMAGE_DIR + "/down_inactive.png")
		self.im_upload = gtk.Image()
		self.im_upload.set_from_pixbuf(up)
		self.im_download = gtk.Image()
		self.im_download.set_from_pixbuf(down)
		self.im_upload.set_alignment(1, 0.5)
		self.im_download.set_alignment(1, 0.5)
		

		
		self.down_rate = gtk.Label()
		self.down_rate.show()
		self.down_rate.set_alignment(1, 0.5)
		

		self.statusbar_container.pack_start(self.down_rate, True, True)
		
		self.statusbar_container.pack_start(gtk.VSeparator(), False, False)
		
		self.statusbar_container.pack_start(self.im_upload, False, False)
		self.statusbar_container.pack_start(self.im_download, False, False)
		self.statusbar_container.show_all()
		
		self.up_blinker = animation(self.im_upload, ["/up_inactive.png", "/up_active.png"])
		#self.down_blinker = animation(self.im_download, ["/down_inactive.png", "/down_active.png"])
		self.down_blinker = animation(self.im_download, ["/down_inactive.png", "/down_active.png"])
		
	def set_blinker_by_speed(self, blinker, speed):
		
		if speed > 0 and not blinker.status():
			blinker.start()
			
		if speed > (30*1024) and blinker.status():
			blinker.set_rate(20)
		elif speed > (20*1024) and blinker.status():
			blinker.set_rate(15)
		elif speed > (10*1024) and blinker.status():
			blinker.set_rate(10)
		elif speed > 1024 and blinker.status():
			blinker.set_rate(5)
		elif speed == 0 and blinker.status():

			blinker.stop()
		else:
			blinker.set_rate(1)
	
	
	def _update(self):
		if Globals.window.visible():

				
			if self.adapter != Globals.Settings.adapter:
				self.up_speed.reset()
				self.down_speed.reset()

			
			self.adapter = Globals.Settings.adapter
			
			devinfo = blueman.device_info(self.adapter)
			_tx = devinfo["stat"]["byte_tx"]
			_rx = devinfo["stat"]["byte_rx"]

			tx, s_tx = self.format_bytes(_tx)
			rx, s_rx = self.format_bytes(_rx)
		
			_u_speed = self.up_speed.calc(_tx)
			_d_speed = self.down_speed.calc(_rx)
		
			self.set_blinker_by_speed(self.up_blinker, _u_speed)
			self.set_blinker_by_speed(self.down_blinker, _d_speed)
		

		
			u_speed, s_u_speed = self.format_bytes(_u_speed)
			d_speed, s_d_speed = self.format_bytes(_d_speed)
		
			self.set_data(tx, s_tx, rx, s_rx, u_speed, s_u_speed, d_speed, s_d_speed)
		
		return 1

	def format_bytes(self, size):
		ret = 0.0
		size = float(size)
		suffix = ""
		if size < 1024:
			ret = size
			suffix = "B"
		elif size > 1024 and size < (1024*1024):
			ret = size / 1024
			suffix = "kB"
		elif size > (1024*1024) and size < (1024*1024*1024):
			ret = size / (1024*1024)
			suffix = "mB"
		else:
			ret = size / (1024*1024*1024)
			suffix="gB"
			
		return (ret, suffix)

	def start_update(self):
		self._update()
		self.timer = gobject.timeout_add (1000, self._update)
		
	def stop_update(self):
		if self.timer:
			gobject.source_remove(self.timer)
	
	def set_data(self, uploaded, u_name, downloaded, d_name, u_speed, us_name, d_speed, ds_name):
		self.down_rate.set_markup('<b>U:</b> %.2f %s <i>%.2f %s/s</i> <b>D:</b> %.2f %s <i>%.2f %s/s</i>' % (uploaded, u_name, u_speed, us_name, downloaded, d_name, d_speed, ds_name))

