#
#
# blueman - toolbar module
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import gtk
import os

from blueman.Main.config_parser import config_parser as config

from blueman.Gui.my_device import my_device
from blueman.Gui.properties import properties

_ = Globals._


class toolbar():
	def __init__(self, xml):
		
		self.xml = xml
		self.inquiry1 = self.xml.get_widget("inquiry1")
		self.listseen1 = self.xml.get_widget("listseen1")
		self.bond1 = self.xml.get_widget("bond1")
		self.addfav1 = self.xml.get_widget("addfav1")
		self.properties1 = self.xml.get_widget("properties1")
		self.sendfile1 = self.xml.get_widget("sendfile1")
		self.browse1 = self.xml.get_widget("browse1")
		self.mydevice1 = self.xml.get_widget("mydevice1")
		self.favourites1 = self.xml.get_widget("favourites1")
		
		self.set_icon(self.inquiry1,Globals.IMAGE_DIR + "/inquiry.png");
		self.set_icon(self.listseen1,Globals.IMAGE_DIR + "/listseen.png");
		self.set_icon(self.bond1,Globals.IMAGE_DIR + "/bond.png");
		self.set_icon(self.addfav1,Globals.IMAGE_DIR + "/addfav.png");
		self.set_icon(self.properties1,Globals.IMAGE_DIR + "/properties.png");
		self.set_icon(self.sendfile1,Globals.IMAGE_DIR + "/sendfile.png");
		self.set_icon(self.browse1,Globals.IMAGE_DIR + "/browse.png");
		self.set_icon(self.mydevice1,Globals.IMAGE_DIR + "/mydevice.png");
		self.set_icon(self.favourites1,Globals.IMAGE_DIR + "/favs.png");
		
		self.xml.signal_connect("on_bond_clicked", self.on_bond_clicked)
		self.xml.signal_connect("on_favorites_clicked", self.on_favorites_clicked)
		self.xml.signal_connect("on_inquiry_clicked", self.on_inquiry_clicked)
		self.xml.signal_connect("on_list_seen_clicked", self.on_list_seen_clicked)
		self.xml.signal_connect("on_send_file_clicked", self.on_send_file_clicked)
		self.xml.signal_connect("on_browse_clicked", self.on_browse_clicked)
		self.xml.signal_connect("on_properties_clicked", self.on_properties_clicked)
		self.xml.signal_connect("on_mydevice_clicked", self.on_mydevice_clicked)
		self.xml.signal_connect("on_adfav_clicked", self.on_adfav_clicked)
		
		
	def enable_buttons(self):
		self.bond1.set_sensitive(True)
		self.addfav1.set_sensitive(True)
		self.properties1.set_sensitive(True)
		self.sendfile1.set_sensitive(True)
		self.browse1.set_sensitive(True)
		Globals.window.mi_trust.set_sensitive(True)

		
	def disable_buttons(self):
		self.bond1.set_sensitive(False)
		self.addfav1.set_sensitive(False)
		self.properties1.set_sensitive(False)
		self.sendfile1.set_sensitive(False)
		self.browse1.set_sensitive(False)
		Globals.window.mi_trust.set_sensitive(False)
		Globals.window.mi_disconnect.set_sensitive(False)
		
	def set_icon(self, button, filename):
		image = gtk.Image()
		image.set_from_file(filename)
		image.show()
		button.set_icon_widget(image)
		
	def disable_all_buttons(self):
		self.bond1.set_sensitive(False)
		self.addfav1.set_sensitive(False)
		self.properties1.set_sensitive(False)
		self.sendfile1.set_sensitive(False)
		self.browse1.set_sensitive(False)
		self.inquiry1.set_sensitive(False)
		self.listseen1.set_sensitive(False)
		self.favourites1.set_sensitive(False)
		self.mydevice1.set_sensitive(False)

	def enable_main_buttons(self):
		self.inquiry1.set_sensitive(True)
		self.listseen1.set_sensitive(True)
		self.favourites1.set_sensitive(True)
		self.mydevice1.set_sensitive(True)
		
		
		
####################### Favorites #############################
	
	def on_favorites_clicked(self, button):
		Globals.window.page = "favorites"
		
		Globals.toolbar.set_icon(Globals.toolbar.addfav1,Globals.IMAGE_DIR + "/remfav.png");
		Globals.toolbar.addfav1.set_label(_("Rem Fav."))
		#self.get_favorites()
		
		
		
		#favs.add("22:33:44:55:66:77","testas")
		CFavorites = config("favorites")    
		list = CFavorites.get()
		print list
		
		for i in range(len(list)):
			addr = list[i][0]
			name = Globals.adapter.GetRemoteName(list[i][0])
			list[i] = (addr, name)
		
		Globals.main_list.reset()
		Globals.main_list.add_from_list(list)
		#favs.save()
		
		Globals.toolbar.disable_buttons()
		
		
	def on_adfav_clicked(self, widget):
		CFavorites = config("favorites")    
		if Globals.window.page == "favorites":
			Globals.Statusbar.push(_("%s Removed") % Globals.main_list.get_selected_row()[0])
			CFavorites.delete(Globals.main_list.get_selected_row()[0])
			Globals.main_list.liststore.remove(Globals.main_list.get_selected_row()[4])
			CFavorites.save()
			
			#print self.selected
			
		else:
			if not CFavorites.add_unique(Globals.main_list.get_selected_row()[0],Globals.adapter.GetRemoteName(Globals.main_list.get_selected_row()[0])) == False:
				CFavorites.save()
				CFavorites.refresh()
				Globals.Statusbar.push(_("%s Added To Favorites") % Globals.main_list.get_selected_row()[0])

			else:
				Globals.Statusbar.push(_("%s Already in favorites") % Globals.main_list.get_selected_row()[0])

	        		
############################################################
		
	
####################### Bonding ###########################	
	
	def on_bond_clicked(self, button):
		addr = Globals.main_list.get_selected_row()[0]
		iter = Globals.main_list.get_selected_row()[4]
		
		if Globals.adapter.HasBonding(addr):
	
	
			try:
				Globals.Bonding.Remove(addr)
				Globals.main_list.set_pixbuf(iter, 6, None)
				Globals.toolbar.bond1.set_label(_("Bond")) 
			except:
				#self.set_status(_("Can't remove bonding"))
				pass
		
		else: 
			Globals.Statusbar.push(_("Connecting..."))
			#try:
			#print
			Globals.Bonding.Create(addr)
			#except:
				#self.set_status(_("Can't create bonding"))
				#pass
		
	


##################################################################
		
	

		

############################# inquiry #####################################	
	
	def on_inquiry_clicked(self, button):
		
		if Globals.window.page == "favorites":
			Globals.toolbar.set_icon(Globals.toolbar.addfav1,Globals.IMAGE_DIR + "/addfav.png");
			Globals.toolbar.addfav1.set_label(_("Add Fav."))
		Globals.window.page = "inquiry"
		if Globals.Inquiry.active:
			Globals.Statusbar.push(_("Inquiry Cancelled"))
			Globals.Inquiry.CancelDiscovery()
			return 0
			
		try:
		
			Globals.Inquiry.StartInquiry();
		except Exception, err:
			Globals.Statusbar.push(_("Failed to start inquiry. Reason: %s") % err)
			
	def on_inquiry_finished(self, devices):
		Globals.main_list.reset()
		
		
		Globals.toolbar.disable_buttons()
	
	
		if Globals.window.page == "favorites":
			self.set_icon(Globals.toolbar.addfav1, Globals.IMAGE_DIR + "/addfav.png");
			Globals.toolbar.addfav1.set_label(_("Add Fav."))
		
		Globals.window.page = "inquiry"
		
		
		Globals.main_list.add_from_list(devices, False)
					
		#self.set_status(_("Found %s device(s)") % str(count))
		

###############################################################



				
				

		
	
	def on_list_seen_clicked(self, button):
		
		if Globals.window.page == "favorites":
			Globals.toolbar.set_icon(Globals.toolbar.addfav1, Globals.IMAGE_DIR + "/addfav.png");
			Globals.toolbar.addfav1.set_label(_("Add Fav."))
		
		
		Globals.window.page = "seen"
		Globals.toolbar.disable_buttons()
		try:
			l = Globals.adapter.ListRemoteDevices()
			
			l2 = []
			for i in range(len(l)):
				l2.append((l[i], Globals.adapter.GetRemoteName(l[i]) ))
				
			
			Globals.main_list.reset()
			Globals.main_list.add_from_list(l2)
			
		except Exception, err:
			self.set_status(_("Can't get device list. Reason: %s") % err)
	

		
		
	def on_send_file_clicked(self, widget):
	
		chooser = gtk.FileChooserDialog(_("Open.."), None,gtk.FILE_CHOOSER_ACTION_OPEN,(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,gtk.STOCK_OPEN, gtk.RESPONSE_OK))
		#chooser.show()
		chooser.set_default_response(gtk.RESPONSE_OK)
		
		
		response = chooser.run()
		
		#filename = chooser.get_filename()
		
		if response == gtk.RESPONSE_OK:
			filename = chooser.get_filename()

			dest = Globals.main_list.get_selected_row()[0]

			#self.set_status(_("Sending file..."))
			os.system("gnome-obex-send \"" + filename + "\" --dest=" + dest + " &")
			#os.system("gnome-obex-send \"" + filename + "\" --dest=" + dest + " 2>/dev/null")
		
				
			chooser.destroy()
		
		elif response == gtk.RESPONSE_CANCEL:
			chooser.destroy()

	def on_browse_clicked(self, widget):
	
		dest = Globals.main_list.get_selected_row()[0]
		
		#self.set_status(_("Browsing..."))
		os.system("nautilus --browser  obex://["+dest+"] &")
		
		
	def on_properties_clicked(self, button):
		test = properties()
		test.run()
		
	
			
	def on_mydevice_clicked(self, button):
		my_device()


