#
#
# audio.py
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import gobject
import dbus
import re
from blueman.Services.bluetooth.generic import generic as generic_service
from blueman.Main.introspect_parser import introspect_parser

class audio(generic_service):
	__gtype_name__ = 'audio_service'
	def __init__(self):
		generic_service.__init__(self, "audio")
           		
           	gobject.signal_new("connect", audio, gobject.SIGNAL_RUN_LAST, gobject.TYPE_BOOLEAN, (gobject.TYPE_STRING, gobject.TYPE_STRING, ))
		gobject.signal_new("disconnect", audio, gobject.SIGNAL_RUN_LAST, gobject.TYPE_BOOLEAN, (gobject.TYPE_STRING, gobject.TYPE_STRING, ))
		gobject.signal_new("device-created", audio, gobject.SIGNAL_RUN_LAST, gobject.TYPE_BOOLEAN, (gobject.TYPE_STRING,))
		gobject.signal_new("device-removed", audio, gobject.SIGNAL_RUN_LAST, gobject.TYPE_BOOLEAN, (gobject.TYPE_STRING,))
		gobject.signal_new("default-device-changed", audio, gobject.SIGNAL_RUN_LAST, gobject.TYPE_BOOLEAN, (gobject.TYPE_STRING, gobject.TYPE_STRING, ))

      
        def connect_signals(self):
        	self.add_signal(self.on_connect, "Connected", None, None, None, path_keyword="path", interface_keyword="interface")
        	self.add_signal(self.on_disconnect, "Disconnected", None, None, None, path_keyword="path", interface_keyword="interface")
        	self.add_signal(self.on_device_created, "DeviceCreated", "org.bluez.audio.Manager", None, None)
        	self.add_signal(self.on_device_removed, "DeviceRemoved", "org.bluez.audio.Manager", None, None)
        	self.add_signal(self.on_default_device_changed, "DefaultDeviceChanged", "org.bluez.audio.Manager", None, None, path_keyword="path")

        def get_profiles(self, path):
		ret = []
		try:
			obj = self.bus.get_object(self.service_bus, path)
			isp = dbus.Interface(obj, 'org.freedesktop.DBus.Introspectable')
			p=introspect_parser()
			p.parse(isp.Introspect())
			interfaces = p.get_interfaces()
			for i in range(len(interfaces)):
				fname = self.profile_friendly_name(interfaces[i])
				ret.append((self.get_profile(path, interfaces[i]), interfaces[i], fname))
			
			return ret
		except:
			return []
			
	def profile_friendly_name(self, profile):
		return re.search("org\.bluez\.audio\.(.*)", profile).groups()[0]
			
	def get_profile(self, path, profile):
		obj = self.bus.get_object(self.service_bus, path)
		prof = dbus.Interface(obj, profile)
		return prof

        	
        def get_devices(self):
	       	ret = []
        	devs = self.service_manager.ListDevices()
        	for i in range(len(devs)):
        		obj = self.bus.get_object(self.service_bus, devs[i])
            		dev = dbus.Interface(obj, 'org.bluez.audio.Device')
            		ret.append((dev,devs[i]))
            		
            	return ret
            	
	def on_connect(self, path, interface):
		if re.match("org\.bluez\.audio\.", interface):
			self.emit("connect", path, interface)

		
	def on_disconnect(self, path, interface):
		if re.match("org\.bluez\.audio\.", interface):
			self.emit("disconnect", path, interface)
				
	def on_default_device_changed(self, device, path):
		self.emit("default-device-changed", device, path)	
			
	def on_device_created(self, path):
		self.emit("device-created", path)	
		
	def on_device_removed(self, path):
		self.emit("device-removed", path)

