#
#
# bluetooth.generic.py - generic BlueZ service implementation
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import gobject
import dbus

class generic(gobject.GObject):
	
	def __init__(self, identifier):
		gobject.GObject.__init__(self)
		
		self.signals = []

		self.identifier = identifier
		
		Globals.dbg.info("Initializing Services.bluetooth.%s Class" % identifier, 5)
		
		self.bus = dbus.SystemBus()
		obj = self.bus.get_object('org.bluez', '/org/bluez')
		self.manager = dbus.Interface(obj, 'org.bluez.Manager')
		
		obj = self.bus.get_object('org.bluez', '/org/bluez/service_'+identifier)
		self.service = dbus.Interface(obj, 'org.bluez.Service')
		
		if self.service.IsRunning():
           		self._init_service_bus() 
           		
           	self.connect_service_signals()
           	self.connect_signals()
           	
           		
	def _init_service_bus(self):
		self.service_bus = self.service.GetBusName()
        	obj = self.bus.get_object(self.service_bus, '/org/bluez/'+self.identifier, False)
        	
        	self.service_manager = dbus.Interface(obj, 'org.bluez.'+self.identifier+'.Manager')
        	
        def add_signal(self, func, signal_name, interface, bus, path, group=0, **kwargs):

		if not (func, signal_name, interface, bus, path, group, kwargs) in self.signals:
			Globals.dbg.info("DBus Signal added [ %s, %s, %s ] Group: %s" % (signal_name, interface, path, group), 6)
			self.signals.append((func, signal_name, interface, bus, path, group, kwargs))
			self.bus.add_signal_receiver(func, signal_name, interface, bus, path, **kwargs)
			
	def remove_signals(self, group=0):
		ids = []
		for i in range(len(self.signals)):
			#print str(self.signals[i])+"\n"
			if self.signals[i][5] == group:
				Globals.dbg.info("DBus Signal Removed [ %s, %s, %s] Group: %s" % ( self.signals[i][1], self.signals[i][2], self.signals[i][4], self.signals[i][5] ), 6)
				self.bus.remove_signal_receiver(self.signals[i][0], self.signals[i][1], self.signals[i][2], self.signals[i][3], self.signals[i][4])
				ids.append(i)
		
		ids.reverse()
		for i in range(len(ids)):
			del self.signals[ids[i]]
        
        
        def connect_service_signals(self):	
        	self.add_signal(self.on_start, 'Started', 'org.bluez.Service', 'org.bluez', '/org/bluez/service_'+self.identifier, path_keyword="path")
		self.add_signal(self.on_stop, 'Stopped', 'org.bluez.Service', 'org.bluez', '/org/bluez/service_'+self.identifier, path_keyword="path")
		
	def on_start(self, path):
		self._init_service_bus()
		
	def on_stop(self, path):
		pass
		
    	def stop(self):
        	if self.service.IsRunning():
            		self.service.Stop()
        
    	def start(self):
        	if not self.service.IsRunning():
            		self.service.Start()
        
        
        def connect_signals(self):
        	pass 
