#
#
# network.py
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import gobject
import dbus
from blueman.Services.bluetooth.generic import generic as generic_service

_ = Globals._

class network(generic_service):
	__gtype_name__ = 'network_service'
	def __init__(self):
		generic_service.__init__(self, "network")
		
		
		gobject.signal_new("connect", network, gobject.SIGNAL_RUN_LAST, gobject.TYPE_BOOLEAN, (gobject.TYPE_STRING,))
		gobject.signal_new("disconnect", network, gobject.SIGNAL_RUN_LAST, gobject.TYPE_BOOLEAN, (gobject.TYPE_STRING,))
		gobject.signal_new("connection-created", network, gobject.SIGNAL_RUN_LAST, gobject.TYPE_BOOLEAN, (gobject.TYPE_STRING,))
		gobject.signal_new("connection-removed", network, gobject.SIGNAL_RUN_LAST, gobject.TYPE_BOOLEAN, (gobject.TYPE_STRING,))
		gobject.signal_new("enabled", network, gobject.SIGNAL_RUN_LAST, gobject.TYPE_BOOLEAN, (gobject.TYPE_STRING,))
		gobject.signal_new("disabled", network, gobject.SIGNAL_RUN_LAST, gobject.TYPE_BOOLEAN, (gobject.TYPE_STRING,))

	
	def connect_signals(self):


		self.add_signal(self.on_connect, 'Connected', 'org.bluez.network.Connection', None, None, path_keyword="path")
		self.add_signal(self.on_disconnect, 'Disconnected', 'org.bluez.network.Connection', None, None, path_keyword="path")

		self.add_signal(self.on_connection_created, 'ConnectionCreated', 'org.bluez.network.Manager', None, "/org/bluez/network")
		self.add_signal(self.on_connection_removed, 'ConnectionRemoved', 'org.bluez.network.Manager', None, "/org/bluez/network")

       		self.add_signal(self.on_server_enabled, 'Enabled', 'org.bluez.network.Server', None, None, path_keyword="path")
       		self.add_signal(self.on_server_disabled, 'Disabled', 'org.bluez.network.Server', None, None, path_keyword="path")
       
    
	
	def on_server_enabled(self, path):
		self.emit("enabled", path)
    
    	def on_server_disabled(self, path):
		self.emit("disabled", path)
        
    	def on_connection_created(self, path):
		self.emit("connection-created", path)
    
    	def on_connection_removed(self, path):
		self.emit("connection-removed", path)
    
    	def on_connect(self, path):
		self.emit("connect", path)
        
    	def on_disconnect(self, path):
		self.emit("disconnect", path)
        

    
    	def get_connections(self):
        	if self.service.IsRunning():
            		connections = self.service_manager.ListConnections()
            		ret = []
            		for i in range(len(connections)):
                		obj = self.bus.get_object(self.service_bus, connections[i])
                		conn = dbus.Interface(obj, 'org.bluez.network.Connection')
                		ret.append((conn, connections[i]))
                
            		return ret
        
        	else:
            
            		return []
    
    
	def get_connection(self, path):
		try:
            		obj = self.bus.get_object(self.service_bus, path)
            		conn = dbus.Interface(obj, 'org.bluez.network.Connection')
            		return conn
        	except:
            		return None
    
    	def get_servers(self):
        	ret = []
        	servers = self.service_manager.ListServers()
        	for i in range(len(servers)):
            		obj = self.bus.get_object(self.service_bus, servers[i])
            		serv = dbus.Interface(obj, 'org.bluez.network.Server')
            		ret.append((serv,servers[i]))
            
        	return ret
        	
        def get_server(self, pattern):
        	try:
            		path = self.service_manager.FindServer(pattern)

            		obj = self.bus.get_object(self.service_bus, path)
            		conn = dbus.Interface(obj, 'org.bluez.network.Server')
            		return conn
        	except:
            		return None
        	
        def create_connection(self, addr, uuid, **kwargs):
        	self.service_manager.CreateConnection(addr, uuid, **kwargs)
        	
        def remove_connection(self, path, **kwargs):
        	self.service_manager.RemoveConnection(path, **kwargs)

