#
#
# bluetooth.serial.py - BlueZ serial service implementation
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import gobject
import dbus
from blueman.Services.bluetooth.generic import generic as generic_service

_ = Globals._

class serial(generic_service):
	__gtype_name__ = 'serial_service'
	
	__gsignals__ = {
		'port-created' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_STRING,)),
		'port-removed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_STRING,)),
		'proxy-created' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_STRING,)),
		'proxy-removed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_STRING,))

		
	}
	
	def __init__(self):
		generic_service.__init__(self, "serial")
		
		#self.service_manager.CreateProxy("00001101-0000-1000-8000-00805F9B34FB","/dev/ttyS0")
		
		#print self.get_proxies()[0][0].GetInfo()
		
	def connect_signals(self):
	
		self.add_signal(self.port_created, 'PortCreated', 'org.bluez.serial.Manager', None, None)
		self.add_signal(self.port_removed, 'PortRemoved', 'org.bluez.serial.Manager', None, None)
		self.add_signal(self.proxy_created, 'ProxyCreated', 'org.bluez.serial.Manager', None, None)
		self.add_signal(self.proxy_removed, 'ProxyRemoved', 'org.bluez.serial.Manager', None, None)
		#self.add_signal(self.service_connected, 'ServiceConnected', 'org.bluez.serial.Port', None, None, path_keyword="path")
		#self.add_signal(self.service_disconnected, 'ServiceDisconnected', 'org.bluez.serial.Port', None, None, path_keyword="path")
		
	def port_created(self, path):
		self.emit("port-created", path)
		
	def port_removed(self, path):
		self.emit("port-removed", path)
		
	def proxy_created(self, path):
		self.emit("proxy-created", path)
		
	def proxy_removed(self, path):
		self.emit("proxy-removed", path)
		
#	def service_connected(self, path):
#		pass
#		
#	def service_disconnected(self, path):
#		pass


    	def get_ports(self):

    		ports = self.service_manager.ListPorts()
    		ret = []
    		for i in range(len(ports)):
        		port = self.get_port(ports[i])
        		ret.append((port, ports[i]))
        
    		return ret
    		
    	def get_proxies(self):

    		ports = self.service_manager.ListProxies()
    		ret = []
    		for i in range(len(ports)):
        		port = self.get_proxy(ports[i])
        		ret.append((port, ports[i]))
       		return ret
    		
    	def get_port(self, path):
    		return self.get_interface(path, 'org.bluez.serial.Port')
    		
    	def get_proxy(self, path):
    		return self.get_interface(path, 'org.bluez.serial.Proxy')
    	
    	def get_interface(self, path, interface):
	        obj = self.bus.get_object(self.service_bus, path)
		iface = dbus.Interface(obj, interface)
		return iface

