#
#
# gui.audio.py - audio service gui implementation
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import gtk
from blueman.Gui.device_selector_combobox import device_selector_combobox
from blueman.Gui.generic_list import generic_list

from blueman.Services.gui.generic import generic

import sys

_ = Globals._



class audio(generic):

	
	def __init__(self):
	
		generic.__init__(self, "audio")		
		
		self._connect_in_progress = False
		self.adding = False

		self.b_connect = self.xml.get_widget("b_connect")
		self.b_disconnect = self.xml.get_widget("b_disconnect")
		
		self.b_default = self.xml.get_widget("b_default")
		self.b_remove = self.xml.get_widget("b_remove")
		self.b_add = self.xml.get_widget("b_add")
#		
		self.hb_error = self.xml.get_widget("hb_error")
		self.i_error = self.xml.get_widget("i_error")
		self.l_error = self.xml.get_widget("l_error")
		self.cb_address = self.xml.get_widget("cb_address")
#		
		device_selector_combobox(self.cb_address, self.on_address_changed)

		
#		## -- Device List -- ##
#		
		sw_dev = self.xml.get_widget("sw_devices")
		sw_prof = self.xml.get_widget("sw_profiles")

		self.dev_list = generic_list([
			["icon", str, gtk.CellRendererPixbuf(), {"stock_id":0}, None],
			["name", str, gtk.CellRendererText(), {"markup":1}, _("Name")],
			["address", str, gtk.CellRendererText(), {"text":2}, _("Address")],
			["path", str]
		])

		self.prof_list = generic_list([
			["icon", str, gtk.CellRendererPixbuf(), {"stock_id":0}, None, {"spacing": 0, "sizing": gtk.TREE_VIEW_COLUMN_AUTOSIZE}],
			["name", str, gtk.CellRendererText(), {"markup":1}, None, {"spacing": 0, "sizing": gtk.TREE_VIEW_COLUMN_AUTOSIZE}],
			["interface", str]
		])
		
		sw_dev.add(self.dev_list)
		sw_prof.add(self.prof_list)
		self.dev_list.set_headers_visible(False)
		self.prof_list.set_headers_visible(False)

		
		self.dev_list.show()
		self.prof_list.show()
		
		self.dev_list.connect("cursor-changed", self.on_tv_devices_cursor_changed)
		self.prof_list.connect("cursor-changed", self.on_tv_profiles_cursor_changed)
		
		self.signals.connect("default-device-changed", self.on_default_device_changed)
		self.signals.connect("connect", self.on_connect)
		self.signals.connect("disconnect", self.on_disconnect)
		self.signals.connect("device-created", self.on_device_created)
		self.signals.connect("device-removed", self.on_device_removed)
				
		self.populate_device_list()

		
		self.xml.signal_autoconnect(self)
		
		self.dialog.show()

	
	def populate_device_list(self):
		self.dev_list.clear()
		
		devs = self.service.get_devices()
		
		if len(devs) > 0:
			default = self.service.service_manager.DefaultDevice()
		else:
			return
		
		
		for i in range(len(devs)):
			addr = devs[i][0].GetAddress()
			name = devs[i][0].GetName()
			
			if devs[i][1] == default:
				icon = "gtk-yes"
			else:
				icon = None

			
			self.dev_list.add(address=addr, name="<b>"+name+"</b>", path=devs[i][1], icon=icon)
			
	def populate_profile_list(self, path):
		self.prof_list.clear()
		profiles = self.service.get_profiles(path)
		
		for i in range(len(profiles)):
			connected = profiles[i][0].IsConnected()
			if connected:
				icon = "gtk-connect"
			else:
				icon = None
			
			self.prof_list.add(name=profiles[i][2], interface=profiles[i][1], icon=icon)
			
	def on_tv_devices_cursor_changed(self, widget):
		row = self.dev_list.get(self.dev_list.selected(), "icon", "path")
		self.populate_profile_list(row["path"])
		self.set_prof_button_state(-1)
		
		if row["icon"]:
			self.set_dev_button_state(4|8)
		else:
			self.set_dev_button_state(2|8)
			
		if not self.connect_in_progress() and not self.adding:
			self.set_notice(None)	
			
	def on_tv_profiles_cursor_changed(self, widget):
		prof_row = self.prof_list.get(self.prof_list.selected(), "interface")
		dev_row = self.dev_list.get(self.dev_list.selected(), "path")
		
		connected = self.service.get_profile(dev_row["path"], prof_row["interface"]).IsConnected()
		if not self.connect_in_progress():
			
			if connected:
				self.set_prof_button_state(0)
			else:
				self.set_prof_button_state(1)
		else:
			self.set_prof_button_state(-1)

		if not self.connect_in_progress() and not self.adding:
			self.set_notice(None)		
		
	
	def set_prof_button_state(self, state):
		if state == 0:
			self.b_connect.set_sensitive(False)
			self.b_disconnect.set_sensitive(True)
		elif state == 1:
			self.b_connect.set_sensitive(True)
			self.b_disconnect.set_sensitive(False)
		elif state == -1:
			self.b_connect.set_sensitive(False)
			self.b_disconnect.set_sensitive(False)	
			
	def set_dev_button_state(self, state):
		if state & 2 == 2:
			self.b_default.set_sensitive(True)
			
		if state & 4 == 4:
			self.b_default.set_sensitive(False)
			
		if state & 8 == 8:
			self.b_remove.set_sensitive(True)
			
		if state & 16 == 16:
			self.b_remove.set_sensitive(False)
			
		if state & 32 == 32:
			self.b_add.set_sensitive(True)
			
		if state & 64 == 64:
			self.b_add.set_sensitive(False)			

       		
       	def on_b_remove_clicked(self, widget):
       		dev = self.dev_list.get(self.dev_list.selected(), "path")
       		self.service.service_manager.RemoveDevice(dev["path"])
       		
       	def on_device_removed(self, service, path):
       		self.populate_device_list()
       		self.prof_list.clear()
       		self.set_prof_button_state(-1)
       		self.set_dev_button_state(4|16)
       		
       	def on_device_created(self, service, path):
       		self.populate_device_list()
       		
       	def on_b_add_clicked(self, widget):
       		addr = self.cb_address.get_active_text()
       		self.service.service_manager.CreateDevice(addr, error_handler=self.add_error, reply_handler=self.add_reply)
       		self.set_notice("gtk-info",_("<b>Adding Device...</b>"))
       		self.b_add.set_sensitive(False)
       		self.adding = True
       	
       	def add_reply(self, *args):
       		self.set_notice(None)
       		self.b_add.set_sensitive(True)
       		self.adding = False
       		
       	def add_error(self, err):
       		self.set_notice("gtk-dialog-error","<b>"+str(err).split(": ")[1]+"</b>")
       		self.b_add.set_sensitive(True)
       		self.adding = False
       		
       	def on_address_changed(self, state):
       		if state and not self.adding:
			self.b_add.set_sensitive(True)
		else:
			self.b_add.set_sensitive(False)
       
       	
    ## default devices ##   	
       	def on_b_default_clicked(self, widget):
       		row = self.dev_list.get(self.dev_list.selected(), "path")
       		self.service.service_manager.ChangeDefaultDevice(row["path"])       		
       	
       	def on_default_device_changed(self, service, device, path):
       		self.dev_list_set_default(device)
       
	def dev_list_set_default(self, dev):

        	old = self.dev_list.get_conditional(icon="gtk-yes")
        	self.dev_list.set(old[0], icon = None)
        	
        	found = self.dev_list.get_conditional(path=dev)
        	if len(found) > 0:
			if found[0] == self.dev_list.selected():
				self.set_dev_button_state(4)
			else:
				self.set_dev_button_state(2)
			
			self.dev_list.set(found[0], icon="gtk-yes") 		
     ##  	
       	
       	def on_connect(self, service, path, interface):
		row = self.dev_list.get(self.dev_list.selected(), "path")  
		if row: 		
			if path == row["path"]:
				self.prof_list_set_connected(interface)
        		
       	
       	def prof_list_set_connected(self, arg_interface, cn=True):
		found = self.prof_list.get_conditional(interface = arg_interface)
		
		if cn:
			self.prof_list.set(found[0], icon="gtk-connect")
		else:
			self.prof_list.set(found[0], icon=None)
		
		if found[0] == self.prof_list.selected():
			if cn:
				self.set_prof_button_state(0)
			else:
				self.set_prof_button_state(1)
		else:
			if self.prof_list.selected() == None:
				self.set_prof_button_state(-1)
			else:
				self.set_prof_button_state(1)

        			
        def on_disconnect(self, service, path, interface):
		row = self.dev_list.get(self.dev_list.selected(), "path")
        	if row:	
			if path == row["path"]:
				self.prof_list_set_connected(interface, False)

        			
        def on_b_connect_clicked(self, widget):
		profile = self.get_profile()
		profile.Connect(reply_handler=self.connect_reply, error_handler=self.connect_error)
		self.connect_in_progress(True)
		self.set_notice("gtk-info",_("<b>Connecting...</b>"))
		
	
	def connect_reply(self):
		self.connect_in_progress(False)
		self.set_notice(None)

	
	def connect_error(self, err):
		self.connect_in_progress(False)
		self.set_notice("gtk-dialog-error", "<b>"+str(err).split(": ")[1]+"</b>")

        	
        def on_b_disconnect_clicked(self, widget):
  		profile = self.get_profile()
        	profile.Disconnect()      	
        	
        def get_profile(self):
		prof_row = self.prof_list.get(self.prof_list.selected(), "interface")
		dev_row = self.dev_list.get(self.dev_list.selected(), "path")
        	return self.service.get_profile(dev_row["path"], prof_row["interface"])
        	
        	
        			
	def on_connect_in_progress(self, state):
		
		if state:
			self.set_prof_button_state(-1)	
		else:
			
			if self.prof_list.selected() != None:
				self.set_prof_button_state(0)
			else:
				self.set_prof_button_state(1)	
				
	def connect_in_progress(self, *args):
		if len(args) > 0:
			if args[0]:
				self._connect_in_progress = True
				self.on_connect_in_progress(True)
			else:
				self._connect_in_progress = False
				self.on_connect_in_progress(False)
		else:
			return self._connect_in_progress		

