#
#
# input.py
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import gtk
from blueman.Gui.device_selector_combobox import device_selector_combobox
from blueman.Gui.generic_list import generic_list
from blueman.Services.gui.generic import generic

_ = Globals._

class input(generic):

	def __init__(self):
		generic.__init__(self, "input")

		self.busy = None
		
		sw = self.xml.get_widget("sw")
		
		data = [
			["icon", str, gtk.CellRendererPixbuf(), {"stock_id":0}, None],
			["name", str, gtk.CellRendererText(), {"markup":1}, ""],
			["address", str, gtk.CellRendererText(), {"text":2}, ""],
			["path", str]
		]
		
		self.list = generic_list(data)
		self.list.set_headers_visible(False)
		self.list.connect("cursor-changed", self.on_cursor_changed)
		
		self.b_connect = self.xml.get_widget("b_connect")
		self.b_disconnect = self.xml.get_widget("b_disconnect")
		self.cb_secure = self.xml.get_widget("cb_secure")
		self.cb_address = self.xml.get_widget("cb_address")
		self.b_add = self.xml.get_widget("b_add")
		
		self.b_remove = self.xml.get_widget("b_remove")
		
		device_selector_combobox(self.cb_address, self.on_address_changed)
		

		self.signals.connect("connect", self.on_connect)
		self.signals.connect("disconnect", self.on_disconnect)
		self.signals.connect("device-created", self.on_device_created)
		self.signals.connect("device-removed", self.on_device_removed)

		self.list.show()
		sw.add(self.list)
		
		self.populate()
		
		self.xml.signal_autoconnect(self)
		
		self.dialog.show()
		
	def __del__(self):
		print "Deleting", self

		
	def button_state(self, state):
		if state == 1:
			self.b_connect.set_sensitive(True)
			self.b_disconnect.set_sensitive(False)
		elif state == 0:
			self.b_connect.set_sensitive(False)
			self.b_disconnect.set_sensitive(True)
		elif state == -1:
			self.b_connect.set_sensitive(False)
			self.b_disconnect.set_sensitive(False)			
	
	def populate(self):
		self.list.clear()
		self.button_state(-1)
		self.b_remove.set_sensitive(False)
		devices = self.service.get_devices()
		for i in range(len(devices)):
			addr = devices[i][0].GetAddress()
			name = devices[i][0].GetName()
			connected = devices[i][0].IsConnected()
			path = devices[i][1]
			if connected:
				icon = "gtk-connect"
			else:
				icon = None
				
			self.list.add(icon=icon, name="<b>"+name+"</b>", address=addr, path=path)
			
	def on_cursor_changed(self, ls):
		row = ls.get(ls.selected(), "path")
		dev = self.service.get_device(row["path"])
		if self.busy == None:
			self.set_notice(None)
			if dev.IsConnected():
				self.button_state(0)
			else:
				self.button_state(1)
		else:
			self.button_state(-1)
			
		self.b_remove.set_sensitive(True)
			
	## -- Connect -- ##
	def on_b_connect_clicked(self, widget):
		row = self.list.get(self.list.selected(), "path")
		dev = self.service.get_device(row["path"])
		dev.Connect(error_handler=self.connect_err, reply_handler=self.connect_err)
		self.busy = row["path"]
		self.set_notice("gtk-connect",_("<b>Connecting...</b>"))
		self.button_state(-1)
		
	def connect_reply(self, *args):
		pass

		
	def connect_err(self, err, *args):
		self.button_state(1)
		self.set_notice("gtk-dialog-error", "<b>"+str(err).split(": ")[1]+"</b>")
		self.busy = None
		
	def on_connect(self, service, path):
		Globals.dbg.info("%s input device connected" % path, 7)
		row = self.list.get_conditional(path=path)
		self.list.set(row[0], icon="gtk-connect")
		if row[0] == self.list.selected():
			self.button_state(0)
			
		row = self.list.get(self.list.selected(), "path", "icon")
		if row["path"] == self.busy:
			self.button_state(0)
		else:
			if row["icon"] != None:
				self.button_state(0)
			else:
				self.button_state(1)
		
		self.busy = None
		self.set_notice(None)
	
	## -- Disconnect -- ##
	def on_b_disconnect_clicked(self, widget):
		row = self.list.get(self.list.selected(), "path")
		dev = self.service.get_device(row["path"])
		dev.Disconnect()
		
	def on_disconnect(self, service, path):
		Globals.dbg.info("%s input device disconnected" % path, 7)
		row = self.list.get_conditional(path=path)
		self.list.set(row[0], icon=None)
		if row[0] == self.list.selected():
			self.button_state(1)
		
	
	
	## -- Remove -- ##	
	def on_b_remove_clicked(self, widget):
		row = self.list.get(self.list.selected(), "path")
		dev = self.service.service_manager.RemoveDevice(row["path"])
		
	def on_device_removed(self, service, path):
		Globals.dbg.info("%s input device removed" % path, 7)
		self.populate()
			
		
		
	## -- Add -- ##
	def on_b_add_clicked(self, widget):
		addr = self.cb_address.get_active_text()
		if self.cb_secure.get_active():		
			self.service.service_manager.CreateSecureDevice(addr, reply_handler=self.add_reply, error_handler=self.add_err)
		else:
			self.service.service_manager.CreateDevice(addr, reply_handler=self.add_reply, error_handler=self.add_err)
			
		self.set_notice("gtk-info", _("<b>Adding Device</b>"))
		self.busy = True
		
	def add_reply(self, *args):
		pass
		
	def add_err(self, err, *args):
		self.set_notice("gtk-dialog-error", "<b>"+str(err).split(": ")[1]+"</b>")
		self.busy = None
		
	def on_device_created(self, service, path):
		Globals.dbg.info("%s input device created" % path, 7)
		dev = service.get_device(path)
		if dev.IsConnected():
			icon = "gtk-connect"
		else:
			icon = None
		
		
		self.list.add(icon=icon, name="<b>"+dev.GetName()+"</b>", address=dev.GetAddress(), path=path)
		self.set_notice(None)
		self.busy = None
		
	def on_address_changed(self, state):
		if state and not self.busy:
			self.b_add.set_sensitive(True)
		else:
			self.b_add.set_sensitive(False)

