#
#
# gui.serial.py - serial service gui implementation
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import gtk

from blueman.Gui.device_selector_combobox import device_selector_combobox
from blueman.Gui.generic_list import generic_list
from blueman.Services.gui.generic import generic

class serial(generic):
	
	def __init__(self):
	
		generic.__init__(self, "serial")
		
		self.b_remport = self.xml.get_widget("b_remport")
		self.b_addport = self.xml.get_widget("b_addport")
		self.cbe_port_host = self.xml.get_widget("cbe_port_host")
		self.cb_port_service = self.xml.get_widget("cb_port_service")
		
		device_selector_combobox(self.cbe_port_host, self.on_port_host)
		
		sw_port = self.xml.get_widget("sw_port")
		sw_proxy = self.xml.get_widget("sw_proxy")
		
		data = [
			["device", str, gtk.CellRendererText(), {"markup":0}, "Device"],
			["name", str, gtk.CellRendererText(), {"markup":1}, "Name"],
			["address", str, gtk.CellRendererText(), {"markup":2}, "Address"],
			["service", str, gtk.CellRendererText(), {"text":3}, "Service"],
			["path", str]
		]
		self.port_list = generic_list(data)
		
		sw_port.add(self.port_list)
		self.port_list.show()		
		self.port_list.connect("cursor-changed", self.ports_list_cursor_changed)
		
		
		
		self.populate_ports_list()

				
#		data = [
#			["enabled", str, gtk.CellRendererPixbuf(), {"stock_id":0}, ""],
#			["device", str, gtk.CellRendererText(), {"markup":1}, "Device"],
#			["uuid", str, gtk.CellRendererText(), {"text":2}, "UUID"],
#			["path", str]
#		]
#		
#		self.proxy_list = generic_list(data)
#		sw_proxy.add(self.proxy_list)
#		self.proxy_list.show()	
#		
#		self.populate_proxy_list()
		
		self.signals.connect("port-created", self.port_created)
		self.signals.connect("port-removed", self.port_removed)
		
		self.xml.signal_autoconnect(self)
		
		self.host_valid = False
		
		self.busy_port = False
		self.busy_proxy = False
		
		self.dialog.show()
	##################################################################################
	###################						##################
	###################		   PORTS part			##################
	###################						##################
	################################################################################## 
	
	def populate_ports_list(self):
		self.port = None
		self.set_port_buttons(False)
		ports = self.service.get_ports()
		self.port_list.clear()
		for i in range(len(ports)):
			port = ports[i][0]
			self.port_list.add(device=port.GetDevice(), address=port.GetAddress(), name=port.GetName(), service=port.GetServiceName(), path=ports[i][1])
		
	
	
	def ports_list_cursor_changed(self, widget):
		row = self.port_list.get(self.port_list.selected(), "path")	
		self.port = self.service.get_port(row["path"])
		self.port.path = row["path"]
		
		self.set_port_buttons(True)
		if not self.busy_port:
			self.set_notice(None, suffix="port")
			
		
	def set_port_buttons(self, state):
		if state:
			self.b_remport.set_sensitive(True)
		else:
			self.b_remport.set_sensitive(False)
		
	def on_port_host(self, state):
		if state:
			self.host_valid = True
		else:
			self.host_valid = False
			
		self.pre_add_checkup()
		
	def on_b_remport_clicked(self, widget):
		self.service.service_manager.RemovePort(self.port.path)
		
	def port_created(self, service, path):
		self.populate_ports_list()
		
	def port_removed(self, service, path):
		self.populate_ports_list()
	
	def on_cb_port_service_changed(self, widget):
		self.pre_add_checkup()
		
	def pre_add_checkup(self):
		name = self.cb_port_service.get_active_text()
			
		if name != None and self.host_valid:
			self.b_addport.set_sensitive(True)
		else:
			self.b_addport.set_sensitive(False)
			
	def on_b_addport_clicked(self, widget):
		friendly_name = self.cb_port_service.get_active_text().split(":")[0]
		address = self.cbe_port_host.get_active_text()
		
		self.service.service_manager.CreatePort(address, friendly_name, error_handler=self.add_err, reply_handler=self.add_reply)
		
		self.set_notice("gtk-info", "<b>Adding Serial Port</b>", suffix="port")
		self.busy_port = True
	
	def add_err(self, err):
		
		self.set_notice("gtk-dialog-error", "<b>"+str(err).split(": ")[1]+"</b>", suffix="port")
		self.busy_port = False
		
	def add_reply(self, path):
		
		self.set_notice(None, suffix="port")
		self.busy_port = False
		
		
	##################################################################################
	###################						##################
	###################		   PROXIES part			##################
	###################						##################
	################################################################################## 	
	
#	def populate_proxy_list(self):
#		self.proxy = None
#		self.set_proxy_buttons(False)
#		proxies = self.service.get_proxies()
#		self.proxy_list.clear()
#		for i in range(len(proxies)):
#			proxy = proxies[i][0]
#			proxy_info = proxy.GetInfo()
#			device = proxy_info["address"]
#			enabled = proxy_info["enabled"]
#			uuid = proxy_info["uuid"]
#			self.proxy_list.add(device=device, uuid=uuid, path=proxies[i][1])
#		
#	def set_proxy_buttons(self, state):
#		if state:
#			self.b_remport.set_sensitive(True)
#		else:
#			self.b_remport.set_sensitive(False)		
		
