#
#
# service_manager.py
# (c) 2007 Valmantas Paliksa <walmis at balticum-tv dot lt>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import blueman.Globals as Globals
import gtk

from blueman.Gui.generic_dialog import generic_dialog

from blueman.Services.gui.audio import audio as audio_service
from blueman.Services.gui.input import input as input_service
from blueman.Services.gui.network import network as network_service
from blueman.Services.gui.serial import serial as serial_service

from blueman.Services.autostart import autostart

from blueman.Main.signal_handler import signal_handler

_ = Globals._

class service_manager(generic_dialog):
	
	def __init__(self):
		self.config_instance = None
		self.signals_connected = False
		
	
		generic_dialog.__init__(self, "services.glade", "services")

		
		self.init_service("network")
		self.init_service("audio")
		self.init_service("input")
		self.init_service("serial")
		
		

		
#	def __del__(self):
#		print "delling"	
	
	def __dialog_response__(self, dialog, response):
		for k, v in Globals.Services.list().iteritems():
			v.remove_signals(1)
		
		self.__destroy__()
	
	def on_service_start(self, path):
		id = path.split("_")[1]
		self.set_service_state(id, 1)
		
	def on_service_stop(self, path):
		id = path.split("_")[1]
		self.set_service_state(id, 0)
		if self.config_instance != None:
			if self.config_instance[1] == id:
				self.config_instance[0].__destroy__()
				self.config_instance = None
		
	def init_service(self, id):
		status = Globals.Services.get_service_status(id)
		if not self.signals_connected:
			s = Globals.Services.get(id)
			s.add_signal(self.on_service_start, 'Started', 'org.bluez.Service', 'org.bluez', None, 1, path_keyword="path")
			s.add_signal(self.on_service_stop, 'Stopped', 'org.bluez.Service', 'org.bluez', None, 1, path_keyword="path")
			self.signals_connected = True
		
		b = self.xml.get_widget("b_"+id)
		tb = self.xml.get_widget("tb_"+id)
		l = self.xml.get_widget("l_"+id)
		cb = self.xml.get_widget("cb_"+id)
		
		self.set_service_state(id, status)
		
		ats=autostart(id)
		if ats.is_enabled():
			cb.set_active(True)
	
		
		b.connect("clicked", self.on_preferences, id)
		tb.connect("toggled", self.on_toggled, id)
		cb.connect("toggled", self.on_autostart_toggled, id)
		
		

		
	def on_autostart_toggled(self, widget, id):
		ats=autostart(id)
		enabled = ats.is_enabled()
		
		if widget.get_active() and not enabled:
			if not ats.enable():
				widget.set_active(False)
		
		elif not widget.get_active() and enabled:
			if not ats.disable():
				widget.set_active(True)

	def on_preferences(self, widget, id):

		self.signals = {}
		
		if id == "audio":
			s=audio_service()
			self.signals[s] = signal_handler(s)
			self.signals[s].connect("dialog-destroyed", self.service_dialog_destroyed)
			self.config_instance = (s, id)
		
		elif id == "network":
			s = network_service()
			self.signals[s] = signal_handler(s)
			self.signals[s].connect("dialog-destroyed", self.service_dialog_destroyed)
			self.config_instance = (s, id)
		
		elif id == "input":
			s = input_service()	
			self.signals[s] = signal_handler(s)
			self.signals[s].connect("dialog-destroyed", self.service_dialog_destroyed)			
			self.config_instance = (s, id)
			
		elif id == "serial":
			s = serial_service()	
			self.signals[s] = signal_handler(s)
			self.signals[s].connect("dialog-destroyed", self.service_dialog_destroyed)			
			self.config_instance = (s, id)		
		
	def service_dialog_destroyed(self, dialog):
		self.signals[dialog].deinit()
		del self.signals[dialog]
		self.config_instance = None
	
	
	def on_toggled(self, widget, id):
		if widget.get_active():
			try:
				Globals.Services.get(id).service.Start()
			except:
				pass
		else:
			try:
				Globals.Services.get(id).service.Stop()
			except:
				pass		
		print widget, id
	
	
	def set_service_state(self, id, state):
		b = self.xml.get_widget("b_"+id)
		tb = self.xml.get_widget("tb_"+id)
		l = self.xml.get_widget("l_"+id)
		
		if state == 1:
			b.set_sensitive(True)
			tb.set_sensitive(True)
			tb.set_active(True)
			tb.set_label(_("ON"))
			l.set_sensitive(True)

		elif state == 0:
			b.set_sensitive(False)
			tb.set_sensitive(True)
			tb.set_active(False)
			tb.set_label(_("OFF"))
			l.set_sensitive(True)
		elif state == -1:
			b.set_sensitive(False)
			tb.set_sensitive(False)
			l.set_sensitive(False)						
   	
